Builder classes
---------------

🤗 Datasets relies on two main classes during the dataset building process: :class:`datasets.DatasetBuilder` and :class:`datasets.BuilderConfig`.

.. autoclass:: datasets.DatasetBuilder

.. autoclass:: datasets.GeneratorBasedBuilder

.. autoclass:: datasets.BeamBasedBuilder

.. autoclass:: datasets.ArrowBasedBuilder

.. autoclass:: datasets.BuilderConfig

.. autoclass:: datasets.DownloadManager

.. autoclass:: datasets.GenerateMode

.. autoclass:: datasets.SplitGenerator

.. autoclass:: datasets.Split

.. autoclass:: datasets.NamedSplit

.. autoclass:: datasets.NamedSplitAll

.. autoclass:: datasets.ReadInstruction

.. autoclass:: datasets.utils::DownloadConfig

.. autoclass:: datasets.utils::Version
